@@ -54,7 +54,7 @@ __end_line__           -- contents of the line in README where the
 
 __author__             -- author name
 __author_email__       -- author e-mail address
-__url__                -- home URL for the author or progra
+__url__                -- home URL for the author or program
 
 __download_url__       -- URL for downloading the program; should
                           not be needed, use __url_base__ and
@@ -65,11 +65,12 @@ __url_base__           -- base URL for download; assumes that the
                           omitted, the PyPI base URL will be used
 __url_ext__            -- extension for the download file; can be
                           ('tar.gz', 'zip', 'exe', 'dmg'); defaults
-                          to 'tar.gz'
+                          to 'tar.gz' if this and the next variable
+                          are both omitted
 __url_type__           -- type of file being downloaded; can be
                           a valid __url_ext__ value or a valid
-                          value for os.name ('posix', 'nt', and
-                          'mac' are currently supported); if omitted,
+                          value for os.name ('posix' and 'nt'
+                          are currently supported); if omitted,
                           __url_ext__ (or its default) is used
 
 __license__            -- the name of the distribution license (valid
@@ -157,8 +158,7 @@ __package_dirs__       -- list of subdirectories of the root of the
                           source tree that contain packages; if this is
                           omitted, any subdirectory that contains an
                           __init__.py file will be treated as a package
-                          (this default should generally be sufficient);
-                          note that the logic
+                          (this default should generally be sufficient)
 __package_data__       -- mapping of package names to lists of data
                           files; this should generally not be needed
                           as the default package finding algorithm
@@ -248,8 +248,9 @@ script's globals as described above.
 
 import sys
 import os
+from itertools import imap, izip
 
-SETUPHELPER_VERSION = (0, 4, 2)
+SETUPHELPER_VERSION = (0, 4, 3)
 
 def version_tuple(ver_s, dev=False):
     """
@@ -261,7 +262,7 @@ def version_tuple(ver_s, dev=False):
     
     ver_t = ver_s.split('.')
     try:
-        result = tuple(map(int, ver_t))
+        result = tuple(imap(int, ver_t))
         if dev:
             return (result, ())
         else:
@@ -295,7 +296,7 @@ def version_string(ver_t, dev_t=None):
     """
     
     try:
-        result = '.'.join(map(str, map(int, ver_t)))
+        result = '.'.join(imap(str, imap(int, ver_t)))
         if dev_t is not None:
             result += dev_string(dev_t)
     except ValueError:
@@ -497,7 +498,7 @@ def distutils_default():
                 self.__m = m
                 self.url = m.group()
                 self.scheme, self.hostname, self.domain, self.portspec, self.pathname, \
-                    self.params, self.query, self.fragment = m.groups()        
+                    self.params, self.query, self.fragment = m.groups()
         
         try:
             allowed_extensions = archive_extensions[sys.platform]
@@ -536,7 +537,7 @@ def distutils_default():
         def version_tuple(verstr, length=4):
             """ Return tuple of version numbers, padded with -1 to length to make sorting easier. """
             t = verstr.split('.')
-            return tuple(map(int, t) + [-1]*(length - len(t)))
+            return tuple(imap(int, t) + [-1]*(length - len(t)))
         version_tuple = staticmethod(version_tuple)
         
         def find_archives_in_iterable(self, iterable, progname):
@@ -728,11 +729,11 @@ def distutils_default():
                         os.system(filename)
                         unpack_dir = None
                 else:
-                    try:
-                        unpack_dir = [dname for dname in os.listdir(".") if os.path.isdir(dname)
-                            and dname.startswith(req)][0]
-                    except IndexError:
-                        unpack_dir = None
+                    unpack_dir = None
+                    for dname in os.listdir("."):
+                        if os.path.isdir(dname) and dname.startswith(req):
+                            unpack_dir = dname
+                            break
                 
                 # Chdir to the source root and run setup with same args as ours
                 if unpack_dir and os.path.isdir(unpack_dir):
@@ -837,7 +838,7 @@ def distutils_setuptools():
 
 # This will be used to process the __license__ variable below
 
-license_map = dict(zip(
+license_map = dict(izip(
     ("PSF", "GNU GPL"), """
 License :: OSI Approved :: Python Software Foundation License
 License :: OSI Approved :: GNU General Public License (GPL)
@@ -1149,10 +1150,11 @@ class SetupHelper(object):
             if not hasattr(self, '__script_root__'):
                 self.__script_root__ = "scripts"
             if os.path.isdir(self.__script_root__):
-                self.__scripts__.extend("%s/%s" % (directory, filename)
-                    for directory, subdirs, files in os.walk(self.__script_root__)
-                        if not "." in directory
-                    for filename in files if not filename.startswith("."))
+                for directory, subdirs, files in os.walk(self.__script_root__):
+                    if "." not in directory:
+                        for filename in files:
+                            if not filename.startswith("."):
+                                self.__scripts__.append("%s/%s" % (directory, filename))
         if hasattr(self, '__script_root__'):
             del self.__script_root__
         if not hasattr(self, '__data_files__'):
@@ -1167,11 +1169,11 @@ class SetupHelper(object):
                         pathprefix = "lib"
                     else:
                         pathprefix = "share/%s" % self.__progname__
-                    self.__data_files__.extend(("%s/%s" % (pathprefix, directory),
-                        ["%s/%s" % (directory, filename) for filename in files
-                            if not filename.startswith(".")])
-                        for directory, subdirs, files in os.walk(datadir)
-                            if files and not "." in directory)
+                    for directory, subdirs, files in os.walk(datadir):
+                        if files and ("." not in directory):
+                            self.__data_files__.append(("%s/%s" % (pathprefix, directory),
+                                ["%s/%s" % (directory, filename) for filename in files
+                                    if not filename.startswith(".")]))
                     self.__manifest_in__.append("recursive-include %s *.*\n" % datadir)
         if not self.__scripts__:
             del self.__scripts__
@@ -1215,7 +1217,7 @@ class SetupHelper(object):
                 self.__url_ext__ = 'tar.gz'
             else:
                 if self.__url_types__ is None:
-                    self.__url_types__ = {'posix': "tar.gz", 'nt': "zip", 'mac': "dmg"}
+                    self.__url_types__ = {'posix': "tar.gz", 'nt': "zip"}
                 try:
                     self.__url_ext__ = self.__url_types__[self.__url_type__]
                 except KeyError:
@@ -1263,7 +1265,7 @@ class SetupHelper(object):
     def process_requires(self):
         # Grab setup options from our sys.argv so we can use the same
         # ones when processing requirements
-        setup_opts = " ".join(opt for opt in sys.argv[1:] if opt not in ("python", "setup.py"))
+        setup_opts = " ".join([opt for opt in sys.argv[1:] if opt not in ("python", "setup.py")])
         
         if hasattr(self, '__progname__'):
             # Check to see if we need to even process requirements
