@@ -28,13 +28,7 @@ def run_doctest(filename):
 def get_unittests(pyname):
     result = []
     mod = __import__(pyname)
-    for attrname in dir(mod):
-        obj = getattr(mod, attrname)
-        try:
-            if issubclass(obj, (unittest.TestCase, unittest.TestSuite)):
-                result.append(obj())
-        except TypeError:
-            pass
+    result.append(unittest.defaultTestLoader.loadTestsFromModule(mod))
     return result
 
 def run_tests():
